pub struct Config {
pub git_protocol: GitProtocol,
pub editor: Option<String>,
pub prompt: Prompt,
pub pager: Option<String>,
pub aliases: HashMap<String, String>,
pub http_unix_socket: Option<String>,
pub browser: Option<String>,
}Expand description
Config representation for gh CLI.
Fields
git_protocol: GitProtocolWhat protocol to use when performing git operations.
editor: Option<String>What editor gh should run when creating issues, pull requests, etc. If blank, will refer to environment.
prompt: PromptWhen to interactively prompt. This is a global config that cannot be overridden by hostname.
pager: Option<String>A pager program to send command output to, e.g. “less”. Set the value to “cat” to disable the pager.
aliases: HashMap<String, String>Aliases allow you to create nicknames for gh commands.
http_unix_socket: Option<String>The path to a unix socket through which send HTTP connections. If blank, HTTP traffic will be handled by default transport.
browser: Option<String>What web browser gh should use when opening URLs. If blank, will refer to environment.
Implementations